/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package javax.validation;

import java.util.List;

/**
 * @version $Rev$ $Date$
 */
public interface Path extends Iterable<Path.Node> {

    interface Node {
        String getName();

        boolean isInIterable();

        Integer getIndex();

        Object getKey();

        // @since 1.1

        ElementKind getKind();

        <T extends Node> T as(Class<T> nodeType);
    }

    // @since 1.1

    interface MethodNode extends Node {
        List<Class<?>> getParameterTypes();
    }

    interface ConstructorNode extends Node {
        List<Class<?>> getParameterTypes();
    }

    interface ReturnValueNode extends Node {
    }

    interface ParameterNode extends Node {
        int getParameterIndex();
    }

    interface CrossParameterNode extends Node {
    }

    interface BeanNode extends Node {
    }

    interface PropertyNode extends Node {
    }
}

